GrapheR-package:
A Multi-Platform GUI for Drawing Customizable Graphs in R
Description
A multi-platform user interface for drawing highly customizable graphs in R. It aims to be a valuable help to quickly draw publishable graphs without any knowledge of R commands. Six kinds of graph are available: histogram, box-and-whisker plot, bar plot, pie chart, curve and scatter plot.
Arguments
Details
Package:
GrapheR
Type:
Package
Version:
1.9-85
Date:
2015-10-17
License:
GPL-2
LazyLoad:
yes
References
Dalgaard P (2001) A Primer on the R-Tcl/Tk Package.
R News, 1(3), 27--31.
Dalgaard P (2002) Changes to the R-Tcl/Tk Package.
R News, 2(3), 25--27.
Herv M (2011) GrapheR: a multiplatform GUI for drawing customizable graphs in R.
The R Journal, 3(2), 45--53.